@@ -20,6 +20,7 @@ class AssembledExam:
 
 @dataclass(frozen=True)
 class Question:
+    id: str
     name: str
     prompt: Text
     autograde_output: str
@@ -114,6 +115,7 @@ def assemble_exam(
             assert len(available_options) == len(student_options)
 
             assembled_question = OptionQuestion(
+                id=question["id"],
                 name=question_name,
                 prompt=question_text,
                 options=available_options,
@@ -129,11 +131,14 @@ def assemble_exam(
 
         else:
             assembled_question = TextQuestion(
+                id=question["id"],
                 name=question_name,
                 prompt=question_text,
                 autograde_output=autograde_output,
                 response=response.get(question["id"], "").replace("\t", " " * 4),
-                height=question.get("options") or 1,
+                height=question.get("options") or 1
+                if question["type"].startswith("long")
+                else 1,
             )
 
         questions.append(assembled_question)
