@@ -36,6 +36,9 @@ class LineBuffer:
         line = self._pop()
         stripped = line.rstrip()
         while stripped.endswith("\\"):
+            if stripped.endswith(r"\\"):
+                line = stripped[:-1]
+                break
             line = stripped[:-1] + "\n" + self._pop()
             stripped = line.rstrip()
         return line
@@ -197,13 +200,13 @@ def parse_input_lines(lines):
                 "Multiple INPUT directives found for a {}".format(directive)
             )
         if directive == "SHORT_ANSWER":
-            return "short_answer", None, None
+            return "short_answer", rest.strip(), None
         elif directive == "SHORT_CODE_ANSWER":
-            return "short_code_answer", None, None
+            return "short_code_answer", rest.strip(), None
         try:
-            num_lines = int(rest or "10")
+            num_lines = float(rest or "10")
         except TypeError:
-            raise SyntaxError("Expected integer as option for {}".format(directive))
+            raise SyntaxError("Expected number as option for {}".format(directive))
         if directive == "LONG_ANSWER":
             return "long_answer", num_lines, None
         elif directive == "LONG_CODE_ANSWER":
@@ -349,6 +352,8 @@ def consume_rest_of_group(buff, end, id_factory):
             group["points"] = points
             group["fixed"] = is_fixed
             elements.append(group)
+        elif mode == "BEGIN" and directive == "NEWPAGE":
+            group_contents.append("\\newpage")
         elif mode == "END" and directive == end:
             return {
                 "type": "group",
