@@ -7,6 +7,7 @@ from io import BytesIO
 from pikepdf import Pdf, Encryption
 import click
 import pytz
+from tqdm import tqdm
 
 from examtool.api.database import get_exam, get_roster
 from examtool.api.utils import sanitize_email
@@ -33,6 +34,18 @@ from examtool.cli.utils import (
     is_flag=True,
     help="Run the compile twice for each student to fix weird rendering bugs.",
 )
+@click.option(
+    "--latex-prefix",
+    default=None,
+    help="Path to custom LaTeX prefix",
+    type=click.Path(),
+)
+@click.option(
+    "--latex-suffix",
+    default=None,
+    help="Path to custom LaTeX suffix",
+    type=click.Path(),
+)
 @click.option("--email", help="The email address of a particular student.")
 @click.option(
     "--exam-type",
@@ -49,15 +62,24 @@ from examtool.cli.utils import (
     default=None,
     help="Generates exam regardless of if student is in roster with the set deadline.",
 )
+@click.option(
+    "--show-pbar",
+    default=False,
+    is_flag=True,
+    help="Suppresses LaTeX compilation output and displays a progress bar instead.",
+)
 def compile_all(
     exam,
     out,
     subtitle,
     do_twice,
+    latex_prefix,
+    latex_suffix,
     email,
     exam_type,
     semester,
     deadline,
+    show_pbar,
 ):
     """
     Compile individualized PDFs for the specified exam.
@@ -88,7 +110,11 @@ def compile_all(
             else:
                 raise ValueError("Email does not exist in the roster!")
 
+    if show_pbar:
+        roster = tqdm(roster)
     for email, deadline, no_watermark in roster:
+        if show_pbar:
+            roster.set_description(f"compiling {email}")
         if not deadline:
             continue
         exam_data = json.loads(exam_str)
@@ -112,6 +138,9 @@ def compile_all(
                 "semester": semester,
             },
             do_twice=do_twice,
+            prefix=latex_prefix,
+            suffix=latex_suffix,
+            suppress_output=show_pbar,
         ) as pdf:
             pdf = Pdf.open(BytesIO(pdf))
             pdf.save(
