@@ -4,11 +4,17 @@ import pathlib
 from multiprocessing.pool import ThreadPool
 
 import click
+import threading
 from tqdm import tqdm
 
 from examtool.api.render_html_export import render_html_exam
 from examtool.api.render_pdf_export import render_pdf_exam
-from examtool.cli.utils import exam_name_option, hidden_output_folder_option
+from examtool.api.gen_latex import render_latex
+from examtool.cli.utils import (
+    exam_name_option,
+    hidden_output_folder_option,
+    OnceSameNameOption,
+)
 import examtool.api.download
 import examtool.api.assemble_export
 
@@ -29,9 +35,38 @@ import examtool.api.assemble_export
     help="Include keyword substitutions in exported question bodies.",
 )
 @click.option(
-    "--via-html/--direct-pdf",
+    "--via-html",
+    "mode",
+    flag_value="html",
     default=True,
-    help="Use an HTML-based PDF exporter or export directly to PDF.",
+    help="Use an HTML-based PDF exporter",
+    cls=OnceSameNameOption,
+)
+@click.option(
+    "--via-latex",
+    "mode",
+    flag_value="latex",
+    help="Embed student responses in the LaTeX PDF",
+    cls=OnceSameNameOption,
+)
+@click.option(
+    "--latex-prefix",
+    default=None,
+    help="Path to custom LaTeX prefix (for --via-latex)",
+    type=click.Path(),
+)
+@click.option(
+    "--latex-suffix",
+    default=None,
+    help="Path to custom LaTeX suffix (for --via-latex)",
+    type=click.Path(),
+)
+@click.option(
+    "--direct-pdf",
+    "mode",
+    flag_value="pdf",
+    help="Export directly to PDF",
+    cls=OnceSameNameOption,
 )
 @click.option(
     "--num-threads",
@@ -41,13 +76,24 @@ import examtool.api.assemble_export
 )
 @hidden_output_folder_option
 def download(
-    exam, out, name_question, sid_question, with_substitutions, via_html, num_threads
+    exam,
+    out,
+    name_question,
+    sid_question,
+    with_substitutions,
+    mode,
+    num_threads,
+    latex_prefix,
+    latex_suffix,
 ):
     """
     Download student submissions for an exam.
     Exams are downloaded as PDFs into a target folder - specify `out` to redirect the folder.
     An `OUTLINE.pdf` is also generated for Gradescope, as is a `summary.csv` for analytics or autograding.
     """
+    if (latex_prefix or latex_suffix) and mode != "latex":
+        assert False, "--latex-prefix/suffix can only be used with --via-latex"
+
     out = out or "out/export/" + exam
     pathlib.Path(out).mkdir(parents=True, exist_ok=True)
 
@@ -77,13 +123,23 @@ def download(
 
         target = os.path.join(out, f"{name}.pdf")
 
-        if via_html:
+        if mode == "html":
             export = render_html_exam(exam)
             export(target)
-
-        else:
+        elif mode == "pdf":
             pdf = render_pdf_exam(exam)
             pdf.output(target)
+        else:
+            with render_latex(
+                exam_json,
+                {},
+                prefix=latex_prefix,
+                suffix=latex_suffix,
+                response=exam,
+                tempdir=f"temp/{threading.get_ident()}",
+            ) as pdf:
+                with open(target, "wb") as f:
+                    f.write(pdf)
 
     with ThreadPool(num_threads) as p:
         list(
