@@ -30,7 +30,13 @@ from examtool.cli.utils import hidden_target_folder_option, exam_name_option, pr
     default=False,
     help="Use the 61A Mailtool, instead of sendgrid",
 )
-def send(exam, target, email, subject, filename, mailtool=False):
+@click.option(
+    "--template",
+    default=None,
+    type=click.File("r"),
+    help="Provide a template to use for the email body",
+)
+def send(exam, target, email, subject, filename, template=None, mailtool=False):
     """
     Email an encrypted PDF to all students taking an exam. Specify `email` to email only a particular student.
     """
@@ -44,17 +50,20 @@ def send(exam, target, email, subject, filename, mailtool=False):
     body = (
         "Hello!\n\n"
         "You have an upcoming exam taking place on exam.cs61a.org. "
-        "You should complete your exam on that website.\n\n"
+        "You should complete your exam on that website (https://exam.cs61a.org/{exam}).\n\n"
         "Course: {course}\n"
         "Exam: {exam}\n\n"
         "However, if you encounter technical difficulties and are unable to do so, "
         "we have attached an encrypted PDF containing the same exam. "
         "You can then email your exam solutions to course staff before the deadline "
         "rather than submitting using exam.cs61a.org. "
-        "To unlock the PDF, its password will be revealed on Piazza when the exam starts.\n\n"
+        "To unlock the PDF, use the password that is revealed on Piazza when the exam starts.\n\n"
         "Good luck, and remember to have fun!"
     ).format(course=course, exam=exam)
 
+    if template:
+        body = template.read().format(course=course, exam=exam)
+
     roster = []
     if email:
         roster = [email]
@@ -87,7 +96,7 @@ def send(exam, target, email, subject, filename, mailtool=False):
         ) as f:
             pdf = base64.b64encode(f.read()).decode("ascii")
         data = {
-            "from": {"email": "cs61a@berkeley.edu", "name": "CS 61A Exam Platform"},
+            "from": {"email": "cs61a@berkeley.edu", "name": f"{course} Exam Platform"},
             "personalizations": [{"to": [{"email": email}], "substitutions": {}}],
             "subject": subject,
             "content": [{"type": "text/plain", "value": body}],
